/* Calculate phase increments for DDS generator
 * ATtiny13 @ 20 MHz
 *
 *             fout * (2^^32)
 * increment = --------------
 *                 fdds
 */

#include <stdio.h>
#include <math.h>

#define	DOUBLE_ROW 0

// double fxtal = 20000000.0;
// double fxtal = 7342800.0;
double fxtal = 1843200.0;

// 5 Dutch CTCSS tone and 3 test frequencies for low-pass testing
double freqs[] = {
	71.9, 77.0, 82.5, 88.5,
	67.0, 250.0, 500.0, 1000.0,
};

int nfreq = sizeof(freqs) / sizeof(double);

int
main(void)
{
	int i;
	double fdds = fxtal / 256.0;
	unsigned long inc;

	printf("=========== 32 bit phase increment ============\n");
	printf("fxtal=%.6f MHz fdds=%.3f KHz period=%.0f usec\n",
		fxtal/1000000.0, fdds/1000.0, 1000000 / fdds);
	printf("fstep=%.8f Hz", fdds / pow(2.0, 32.0));
	for (i=0 ; i < nfreq ; i++) {
		inc = (freqs[i] * pow(2.0, 32.0) / fdds);
#if	DOUBLE_ROW
		if ((i % 2) == 0)
			printf("\n");
		printf("\t0x%08xL /* %.2f Hz */,", inc, freqs[i]);
#else
		printf("\n\t0x%08xL /* %.2f Hz */,", inc, freqs[i]);
#endif
	}
	printf("\n");
	printf("=========== 24 bit phase increment ============\n");
	printf("fxtal=%.6f MHz fdds=%.3f KHz period=%.0f usec\n",
		fxtal/1000000.0, fdds/1000.0, 1000000 / fdds);
	printf("fstep=%.8f Hz", fdds / pow(2.0, 24.0));
	for (i=0 ; i < nfreq ; i++) {
		inc = (freqs[i] * pow(2.0, 24.0) / fdds);
		if ((i % 2) == 0)
			printf("\n");
		printf("\t0x%06x /* %.2f Hz */,", inc, freqs[i]);
	}
	printf("\n");
	printf("=========== 16 bit phase increment ============\n");
	printf("fxtal=%.6f MHz fdds=%.3f KHz period=%.0f usec\n",
		fxtal/1000000.0, fdds/1000.0, 1000000 / fdds);
	printf("fstep=%.8f Hz", fdds / pow(2.0, 16.0));
	for (i=0 ; i < nfreq ; i++) {
		inc = (freqs[i] * pow(2.0, 16.0) / fdds);
		if ((i % 2) == 0)
			printf("\n");
		printf("\t0x%04x /* %.2f Hz */,", inc, freqs[i]);
	}
	printf("\n");
}

